# Making With Code CLI

This package provides the command-line tool `mwc` which accompanies the Making With Code
introductory Computer Science curriculum. `mwc` helps students configure their computers, 
sets up git repositories for course assignemnts, and provides helpers for other course tasks
like running tests and accessing the curriculum.

Teachers will be able to use `mwc` to adminster their courses, including tools for feedback and 
assessment. The overall goal of the project is to provide computational infrastructure to teachers
and schools allowing them to teach CS through open-ended projects using real tools, supporting 
personal relationships with powerful ideas and rich computing cultures. 

## Usage

`mwc` can be installed via pip. However, if you're a student or teacher using 
Making With Code, there is a separate bootstrapping process you should follow. 
Please consult your curriculum website (or ask your teacher) for detailed instructions 
on how and why to use this tool. 

    pip3 install making-with-code-cli

Once installed, you can set up your computer using the `mwc setup` command. Run 
`mwc --help` to see all the commands available.  

## Contact

If you're interested in computing education and want to learn more about Making With Code, 
please contact [Dr. Chris Proctor](https://chrisproctor.net).
